@@ -1,5 +1,5 @@
 package Beam::Runner::Command::minion;
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 # ABSTRACT: Command for L<beam> to run distributed tasks
 
 #pod =head1 SYNOPSIS
@@ -24,8 +24,18 @@ use Module::Runtime qw( use_module compose_module_name );
 
 sub run {
     my ( $class, $cmd, @args ) = @_;
+    if ( !$cmd ) {
+        die "ERROR: No 'beam minion' sub-command specified\n";
+    }
     my $cmd_class = compose_module_name( 'Beam::Minion::Command', $cmd );
-    return use_module( $cmd_class )->run( @args );
+    eval { use_module( $cmd_class ) };
+    if ( $@ ) {
+        if ( $@ =~ m{^Can't locate Beam/Minion/Command/} ) {
+            die "ERROR: No such sub-command: $cmd\n";
+        }
+        die "Error loading module '$cmd_class': $@\n";
+    }
+    return $cmd_class->run( @args );
 }
 
 1;
@@ -40,7 +50,7 @@ Beam::Runner::Command::minion - Command for L<beam> to run distributed tasks
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
